@@ -9,6 +9,7 @@ from IPython.core.display import HTML
 from collections import defaultdict
 import networkx as nx
 import json
+import jsonpickle
 import os
 
 
@@ -29,7 +30,8 @@ class Network(object):
                  notebook=False,
                  bgcolor="#ffffff",
                  font_color=False,
-                 layout=None):
+                 layout=None,
+                 heading=None):
         """
         :param height: The height of the canvas
         :param width: The width of the canvas
@@ -52,6 +54,7 @@ class Network(object):
         self.edges = []
         self.height = height
         self.width = width
+        self.heading = heading
         self.html = ""
         self.shape = "dot"
         self.font_color = font_color
@@ -80,7 +83,8 @@ class Network(object):
                     "Nodes": self.node_ids,
                     "Edges": self.edges,
                     "Height": self.height,
-                    "Width": self.width
+                    "Width": self.width,
+                    "Heading": self.heading
                 },
                 indent=4
             )
@@ -379,13 +383,13 @@ class Network(object):
 
         Usage:
 
-        >>> nodes, edges, height, width, options = net.get_network_data()
+        >>> nodes, edges, heading, height, width, options = net.get_network_data()
         """
         if isinstance(self.options, dict):
-            return (self.nodes, self.edges, self.height,
+            return (self.nodes, self.edges, self.heading, self.height,
                 self.width, json.dumps(self.options))
         else:
-            return (self.nodes, self.edges, self.height,
+            return (self.nodes, self.edges, self.heading, self.height,
                 self.width, self.options.to_json())
 
     def save_graph(self, name):
@@ -427,7 +431,7 @@ class Network(object):
         else:
             template = self.template
 
-        nodes, edges, height, width, options = self.get_network_data()
+        nodes, edges, heading, height, width, options = self.get_network_data()
 
         # check if physics is enabled
         if isinstance(self.options, dict):
@@ -442,6 +446,7 @@ class Network(object):
                                     width=width,
                                     nodes=nodes,
                                     edges=edges,
+                                    heading=heading,
                                     options=options,
                                     physics_enabled=physics_enabled,
                                     use_DOT=self.use_DOT,
@@ -765,10 +770,8 @@ class Network(object):
         """
         self.options.physics.use_force_atlas_2based(locals())
 
-    def to_json(self):
-        return json.dumps(self, default=lambda o: o.__dict__,
-                          sort_keys=True, indent=4)
-
+    def to_json(self, max_depth=1, **args):
+        return jsonpickle.encode(self, max_depth=max_depth, **args)
 
     def set_edge_smooth(self, smooth_type):
         """
